@@ -163,10 +163,9 @@ where
         }
 
         let mut after_send = std::mem::take(&mut self.after_send);
-        let result = self.finish().await;
-        after_send.call(result.is_ok().into());
+        after_send.call(true.into());
         std::mem::forget(after_send);
-
+        let result = self.finish().await;
         result
     }
 
@@ -691,10 +690,8 @@ where
             .map(|cl| cl.len())
         {
             Ok(Some(cl))
-        } else if self.method == Method::Get {
-            Ok(Some(0))
         } else {
-            Err(Error::HeaderMissing("content-length or transfer-encoding"))
+            Ok(Some(0))
         }
     }
 
